==> coyim_0.3.7.orig.tar.gz: coyim-0.3.7/xmpp/tls_test.go <==
package xmpp

import (
	"crypto/tls"
	"crypto/x509"
	"crypto/x509/pkix"

	. "github.com/twstrike/coyim/Godeps/_workspace/src/gopkg.in/check.v1"
)

type TLSXmppSuite struct{}

var _ = Suite(&TLSXmppSuite{})

func (s *TLSXmppSuite) Test_certName_returnsEmptyInformation(c *C) {
	cert := &x509.Certificate{}
	cert.Subject = pkix.Name{}
	res := certName(cert)
	c.Assert(res, Equals, "")
}

func (s *TLSXmppSuite) Test_certName_usesNameInformation(c *C) {
	cert := &x509.Certificate{}
	cert.Subject = pkix.Name{}
	cert.Subject.Organization = []string{"Foo", "Bar.com"}
	cert.Subject.OrganizationalUnit = []string{"Somewhere", "Else", "Above", "Beyond"}
	cert.Subject.CommonName = "test.coyim"
	res := certName(cert)
	c.Assert(res, Equals, "O=Foo/O=Bar.com/OU=Somewhere/OU=Else/OU=Above/OU=Beyond/CN=test.coyim/")
}

func (s *TLSXmppSuite) Test_printTLSDetails_printsUnknownVersions(c *C) {
	mockWriter := mockConnIOReaderWriter{}
	state := tls.ConnectionState{
		Version: 0x0200,
	}

	printTLSDetails(&mockWriter, state)

	c.Assert(string(mockWriter.write), Equals, ""+
		"  SSL/TLS version: unknown\n"+
		"  Cipher suite: unknown\n",
	)
}

func (s *TLSXmppSuite) Test_printTLSDetails_printsCorrectVersions(c *C) {
	mockWriter := mockConnIOReaderWriter{}
	state := tls.ConnectionState{
		Version:     tls.VersionTLS11,
		CipherSuite: 0xc00a,
	}

	printTLSDetails(&mockWriter, state)

	c.Assert(string(mockWriter.write), Equals, ""+
		"  SSL/TLS version: TLS 1.1\n"+
		"  Cipher suite: TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA\n",
	)
}

==> coyim-0.4.1.tar.gz: coyim-0.4.1/xmpp/tls_test.go <==
package xmpp

import (
	"bytes"
	"crypto/tls"
	"crypto/x509"
	"crypto/x509/pkix"

	log "github.com/sirupsen/logrus"
	. "gopkg.in/check.v1"
)

type TLSXmppSuite struct{}

var _ = Suite(&TLSXmppSuite{})

func (s *TLSXmppSuite) Test_certName_returnsEmptyInformation(c *C) {
	cert := &x509.Certificate{}
	cert.Subject = pkix.Name{}
	res := certName(cert)
	c.Assert(res, Equals, "")
}

func (s *TLSXmppSuite) Test_certName_usesNameInformation(c *C) {
	cert := &x509.Certificate{}
	cert.Subject = pkix.Name{}
	cert.Subject.Organization = []string{"Foo", "Bar.com"}
	cert.Subject.OrganizationalUnit = []string{"Somewhere", "Else", "Above", "Beyond"}
	cert.Subject.CommonName = "test.coyim"
	res := certName(cert)
	c.Assert(res, Equals, "O=Foo/O=Bar.com/OU=Somewhere/OU=Else/OU=Above/OU=Beyond/CN=test.coyim/")
}

func (s *TLSXmppSuite) Test_printTLSDetails_printsUnknownVersions(c *C) {
	state := tls.ConnectionState{
		Version: 0x0200,
	}
	ll := log.New()
	buf := new(bytes.Buffer)
	ll.SetOutput(buf)

	printTLSDetails(ll, state)

	c.Assert(buf.String(), Matches, "(?s).*?version=unknown.*?")
	c.Assert(buf.String(), Matches, "(?s).*?cipherSuite=unknown.*?")
}

func (s *TLSXmppSuite) Test_printTLSDetails_printsCorrectVersions(c *C) {
	state := tls.ConnectionState{
		Version:     tls.VersionTLS12,
		CipherSuite: 0xc030,
	}
	ll := log.New()
	buf := new(bytes.Buffer)
	ll.SetOutput(buf)

	printTLSDetails(ll, state)

	c.Assert(buf.String(), Matches, "(?s).*?version=\"TLS 1\\.2\".*?")
	c.Assert(buf.String(), Matches, "(?s).*?cipherSuite=TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384.*?")
}
